@@ -23,76 +23,61 @@ from aliyunsdkarms.endpoint import endpoint_data
 class CreatePrometheusAlertRuleRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'CreatePrometheusAlertRule')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'CreatePrometheusAlertRule','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ProductCode(self):
-		return self.get_query_params().get('ProductCode')
-
-	def set_ProductCode(self,ProductCode):
-		self.add_query_param('ProductCode',ProductCode)
-
-	def get_Expression(self):
+	def get_Expression(self): # String
 		return self.get_query_params().get('Expression')
 
-	def set_Expression(self,Expression):
-		self.add_query_param('Expression',Expression)
-
-	def get_AlertName(self):
+	def set_Expression(self, Expression):  # String
+		self.add_query_param('Expression', Expression)
+	def get_AlertName(self): # String
 		return self.get_query_params().get('AlertName')
 
-	def set_AlertName(self,AlertName):
-		self.add_query_param('AlertName',AlertName)
-
-	def get_Annotations(self):
+	def set_AlertName(self, AlertName):  # String
+		self.add_query_param('AlertName', AlertName)
+	def get_Annotations(self): # String
 		return self.get_query_params().get('Annotations')
 
-	def set_Annotations(self,Annotations):
-		self.add_query_param('Annotations',Annotations)
-
-	def get_ClusterId(self):
+	def set_Annotations(self, Annotations):  # String
+		self.add_query_param('Annotations', Annotations)
+	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
-	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
-
-	def get_DispatchRuleId(self):
+	def set_ClusterId(self, ClusterId):  # String
+		self.add_query_param('ClusterId', ClusterId)
+	def get_DispatchRuleId(self): # Long
 		return self.get_query_params().get('DispatchRuleId')
 
-	def set_DispatchRuleId(self,DispatchRuleId):
-		self.add_query_param('DispatchRuleId',DispatchRuleId)
-
-	def get_Type(self):
+	def set_DispatchRuleId(self, DispatchRuleId):  # Long
+		self.add_query_param('DispatchRuleId', DispatchRuleId)
+	def get_Type(self): # String
 		return self.get_query_params().get('Type')
 
-	def set_Type(self,Type):
-		self.add_query_param('Type',Type)
-
-	def get_Message(self):
+	def set_Type(self, Type):  # String
+		self.add_query_param('Type', Type)
+	def get_Message(self): # String
 		return self.get_query_params().get('Message')
 
-	def set_Message(self,Message):
-		self.add_query_param('Message',Message)
-
-	def get_Labels(self):
+	def set_Message(self, Message):  # String
+		self.add_query_param('Message', Message)
+	def get_Labels(self): # String
 		return self.get_query_params().get('Labels')
 
-	def set_Labels(self,Labels):
-		self.add_query_param('Labels',Labels)
-
-	def get_Duration(self):
+	def set_Labels(self, Labels):  # String
+		self.add_query_param('Labels', Labels)
+	def get_Duration(self): # String
 		return self.get_query_params().get('Duration')
 
-	def set_Duration(self,Duration):
-		self.add_query_param('Duration',Duration)
-
-	def get_NotifyType(self):
+	def set_Duration(self, Duration):  # String
+		self.add_query_param('Duration', Duration)
+	def get_NotifyType(self): # String
 		return self.get_query_params().get('NotifyType')
 
-	def set_NotifyType(self,NotifyType):
-		self.add_query_param('NotifyType',NotifyType)
\ No newline at end of file
+	def set_NotifyType(self, NotifyType):  # String
+		self.add_query_param('NotifyType', NotifyType)
