@@ -23,46 +23,46 @@ from aliyunsdkarms.endpoint import endpoint_data
 class SearchAlertRulesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'SearchAlertRules')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'SearchAlertRules','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AppType(self):
+	def get_AppType(self): # String
 		return self.get_query_params().get('AppType')
 
-	def set_AppType(self,AppType):
-		self.add_query_param('AppType',AppType)
-
-	def get_CurrentPage(self):
+	def set_AppType(self, AppType):  # String
+		self.add_query_param('AppType', AppType)
+	def get_CurrentPage(self): # Integer
 		return self.get_query_params().get('CurrentPage')
 
-	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
-
-	def get_Pid(self):
+	def set_CurrentPage(self, CurrentPage):  # Integer
+		self.add_query_param('CurrentPage', CurrentPage)
+	def get_Pid(self): # String
 		return self.get_query_params().get('Pid')
 
-	def set_Pid(self,Pid):
-		self.add_query_param('Pid',Pid)
+	def set_Pid(self, Pid):  # String
+		self.add_query_param('Pid', Pid)
+	def get_SystemRegionId(self): # String
+		return self.get_query_params().get('SystemRegionId')
 
-	def get_Title(self):
+	def set_SystemRegionId(self, SystemRegionId):  # String
+		self.add_query_param('SystemRegionId', SystemRegionId)
+	def get_Title(self): # String
 		return self.get_query_params().get('Title')
 
-	def set_Title(self,Title):
-		self.add_query_param('Title',Title)
-
-	def get_Type(self):
+	def set_Title(self, Title):  # String
+		self.add_query_param('Title', Title)
+	def get_Type(self): # String
 		return self.get_query_params().get('Type')
 
-	def set_Type(self,Type):
-		self.add_query_param('Type',Type)
-
-	def get_PageSize(self):
+	def set_Type(self, Type):  # String
+		self.add_query_param('Type', Type)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
\ No newline at end of file
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
